@@ -29,18 +29,16 @@ import nova.exception
 from nova.i18n import _
 from nova.i18n import _LE
 from nova import objects
+from nova.policies import server_groups as sg_policies
 
 LOG = logging.getLogger(__name__)
 
 ALIAS = "os-server-groups"
 
 
-authorize = extensions.os_compute_authorizer(ALIAS)
-
-
-def _authorize_context(req):
+def _authorize_context(req, action):
     context = req.environ['nova.context']
-    authorize(context)
+    context.can(sg_policies.POLICY_ROOT % action)
     return context
 
 
@@ -77,7 +75,7 @@ class ServerGroupController(wsgi.Controller):
     @extensions.expected_errors(404)
     def show(self, req, id):
         """Return data about the given server group."""
-        context = _authorize_context(req)
+        context = _authorize_context(req, 'show')
         try:
             sg = objects.InstanceGroup.get_by_uuid(context, id)
         except nova.exception.InstanceGroupNotFound as e:
@@ -88,7 +86,7 @@ class ServerGroupController(wsgi.Controller):
     @extensions.expected_errors(404)
     def delete(self, req, id):
         """Delete an server group."""
-        context = _authorize_context(req)
+        context = _authorize_context(req, 'delete')
         try:
             sg = objects.InstanceGroup.get_by_uuid(context, id)
         except nova.exception.InstanceGroupNotFound as e:
@@ -119,7 +117,7 @@ class ServerGroupController(wsgi.Controller):
     @extensions.expected_errors(())
     def index(self, req):
         """Returns a list of server groups."""
-        context = _authorize_context(req)
+        context = _authorize_context(req, 'index')
         project_id = context.project_id
         if 'all_projects' in req.GET and context.is_admin:
             sgs = objects.InstanceGroupList.get_all(context)
@@ -137,7 +135,7 @@ class ServerGroupController(wsgi.Controller):
     @validation.schema(schema.create_v215, "2.15")
     def create(self, req, body):
         """Creates a new server group."""
-        context = _authorize_context(req)
+        context = _authorize_context(req, 'create')
 
         quotas = objects.Quotas(context=context)
         try:
