@@ -49,10 +49,12 @@ from nova import context
 from nova import db
 from nova.network import manager as network_manager
 from nova.network.security_group import openstack_driver
+from nova import objects
 from nova.objects import base as objects_base
 from nova.tests import fixtures as nova_fixtures
 from nova.tests.unit import conf_fixture
 from nova.tests.unit import policy_fixture
+from nova.tests import uuidsentinel as uuids
 from nova import utils
 
 
@@ -64,6 +66,8 @@ logging.setup(CONF, 'nova')
 cache.configure(CONF)
 
 _TRUE_VALUES = ('True', 'true', '1', 'yes')
+CELL1_NAME = 'cell1'
+
 
 if six.PY2:
     nested = contextlib.nested
@@ -169,7 +173,14 @@ class TestCase(testtools.TestCase):
     Due to the slowness of DB access, please consider deriving from
     `NoDBTestCase` first.
     """
+    # USES_DB is set to False for tests that inherit from NoDBTestCase.
     USES_DB = True
+    # USES_DB_SELF is set to True in tests that specifically want to use the
+    # database but need to configure it themselves, for example to setup the
+    # API DB but not the cell DB. In those cases the test will override
+    # USES_DB_SELF = True but inherit from the NoDBTestCase class so it does
+    # not get the default fixture setup when using a database (which is the
+    # API and cell DBs, and adding the default flavors).
     USES_DB_SELF = False
     REQUIRES_LOCKING = False
 
@@ -211,20 +222,6 @@ class TestCase(testtools.TestCase):
         self.useFixture(conf_fixture.ConfFixture(CONF))
         self.useFixture(nova_fixtures.RPCFixture('nova.test'))
 
-        # NOTE(melwitt): Reset the cached db connection objects
-        context.CELL_CACHE = {}
-
-        if self.USES_DB:
-            self.useFixture(nova_fixtures.Database())
-            self.useFixture(nova_fixtures.Database(database='api'))
-            self.useFixture(nova_fixtures.DefaultFlavorsFixture())
-        elif not self.USES_DB_SELF:
-            self.useFixture(nova_fixtures.DatabasePoisonFixture())
-
-        # NOTE(blk-u): WarningsFixture must be after the Database fixture
-        # because sqlalchemy-migrate messes with the warnings filters.
-        self.useFixture(nova_fixtures.WarningsFixture())
-
         # NOTE(danms): Make sure to reset us back to non-remote objects
         # for each test to avoid interactions. Also, backup the object
         # registry.
@@ -233,6 +230,31 @@ class TestCase(testtools.TestCase):
             objects_base.NovaObjectRegistry._registry._obj_classes)
         self.addCleanup(self._restore_obj_registry)
 
+        # NOTE(danms): Reset the cached list of cells
+        from nova.compute import api
+        api.CELLS = []
+
+        self.cell_mappings = {}
+        self.host_mappings = {}
+        # NOTE(danms): If the test claims to want to set up the database
+        # itself, then it is responsible for all the mapping stuff too.
+        if self.USES_DB:
+            # NOTE(danms): Full database setup involves a cell0, cell1,
+            # and the relevant mappings.
+            self.useFixture(nova_fixtures.Database(database='api'))
+            self._setup_cells()
+            self.useFixture(nova_fixtures.DefaultFlavorsFixture())
+        elif not self.USES_DB_SELF:
+            # NOTE(danms): If not using the database, we mock out the
+            # mapping stuff and effectively collapse everything to a
+            # single cell.
+            self.useFixture(nova_fixtures.SingleCellSimple())
+            self.useFixture(nova_fixtures.DatabasePoisonFixture())
+
+        # NOTE(blk-u): WarningsFixture must be after the Database fixture
+        # because sqlalchemy-migrate messes with the warnings filters.
+        self.useFixture(nova_fixtures.WarningsFixture())
+
         self.useFixture(ovo_fixture.StableObjectJsonFixture())
 
         # NOTE(mnaser): All calls to utils.is_neutron() are cached in
@@ -253,6 +275,39 @@ class TestCase(testtools.TestCase):
 
         self.useFixture(nova_fixtures.ForbidNewLegacyNotificationFixture())
 
+    def _setup_cells(self):
+        """Setup a normal cellsv2 environment.
+
+        This sets up the CellDatabase fixture with two cells, one cell0
+        and one normal cell. CellMappings are created for both so that
+        cells-aware code can find those two databases.
+        """
+        celldbs = nova_fixtures.CellDatabases()
+        celldbs.add_cell_database(objects.CellMapping.CELL0_UUID)
+        celldbs.add_cell_database(uuids.cell1, default=True)
+        self.useFixture(celldbs)
+
+        ctxt = context.get_context()
+        fake_transport = 'fake://nowhere/'
+
+        c0 = objects.CellMapping(
+            context=ctxt,
+            uuid=objects.CellMapping.CELL0_UUID,
+            name='cell0',
+            transport_url=fake_transport,
+            database_connection=objects.CellMapping.CELL0_UUID)
+        c0.create()
+
+        c1 = objects.CellMapping(
+            context=ctxt,
+            uuid=uuids.cell1,
+            name=CELL1_NAME,
+            transport_url=fake_transport,
+            database_connection=uuids.cell1)
+        c1.create()
+
+        self.cell_mappings = {cm.name: cm for cm in (c0, c1)}
+
     def _restore_obj_registry(self):
         objects_base.NovaObjectRegistry._registry._obj_classes = \
                 self._base_test_obj_backup
@@ -285,12 +340,22 @@ class TestCase(testtools.TestCase):
     def flags(self, **kw):
         """Override flag variables for a test."""
         group = kw.pop('group', None)
-        for k, v in six.iteritems(kw):
+        for k, v in kw.items():
             CONF.set_override(k, v, group, enforce_type=True)
 
     def start_service(self, name, host=None, **kwargs):
         svc = self.useFixture(
             nova_fixtures.ServiceFixture(name, host, **kwargs))
+
+        if name == 'compute' and self.USES_DB:
+            ctxt = context.get_context()
+            cell = self.cell_mappings[kwargs.pop('cell', CELL1_NAME)]
+            hm = objects.HostMapping(context=ctxt,
+                                     host=svc.service.host,
+                                     cell_mapping=cell)
+            hm.create()
+            self.host_mappings[hm.host] = hm
+
         return svc.service
 
     def assertJsonEqual(self, expected, observed):
@@ -395,7 +460,7 @@ class APICoverage(object):
     cover_api = None
 
     def test_api_methods(self):
-        self.assertTrue(self.cover_api is not None)
+        self.assertIsNotNone(self.cover_api)
         api_methods = [x for x in dir(self.cover_api)
                        if not x.startswith('_')]
         test_methods = [x[5:] for x in dir(self)
@@ -460,6 +525,21 @@ class MatchType(object):
         return "<MatchType:" + str(self.wanttype) + ">"
 
 
+class MatchObjPrims(object):
+    """Matches objects with equal primitives."""
+    def __init__(self, want_obj):
+        self.want_obj = want_obj
+
+    def __eq__(self, other):
+        return objects_base.obj_equal_prims(other, self.want_obj)
+
+    def __ne__(self, other):
+        return not other == self.want_obj
+
+    def __repr__(self):
+        return '<MatchObjPrims:' + str(self.want_obj) + '>'
+
+
 class ContainKeyValue(object):
     """Checks whether a key/value pair is in a dict parameter.
 
