@@ -31,16 +31,20 @@ class NoAuthReportClient(report.SchedulerReportClient):
     """A SchedulerReportClient that avoids keystone."""
 
     def __init__(self):
-        self._resource_providers = {}
-        self._disabled = False
+        super(NoAuthReportClient, self).__init__()
         # Supply our own session so the wsgi-intercept can intercept
         # the right thing. Another option would be to use the direct
         # urllib3 interceptor.
         request_session = requests.Session()
+        headers = {
+            'x-auth-token': 'admin',
+            'OpenStack-API-Version': 'placement latest',
+        }
         self._client = session.Session(
             auth=None,
             session=request_session,
-            additional_headers={'x-auth-token': 'admin'})
+            additional_headers=headers,
+        )
 
 
 class SchedulerReportClientTests(test.TestCase):
@@ -48,7 +52,7 @@ class SchedulerReportClientTests(test.TestCase):
 
     def setUp(self):
         super(SchedulerReportClientTests, self).setUp()
-        self.flags(auth_strategy='noauth2')
+        self.flags(auth_strategy='noauth2', group='api')
 
         self.app = lambda: deploy.loadapp(CONF)
         self.client = NoAuthReportClient()
@@ -104,6 +108,12 @@ class SchedulerReportClientTests(test.TestCase):
             rp = self.client._get_resource_provider(self.compute_uuid)
             self.assertIsNotNone(rp)
 
+            # We should also have an empty list set of aggregate UUID
+            # associations
+            pam = self.client._provider_aggregate_map
+            self.assertIn(self.compute_uuid, pam)
+            self.assertEqual(set(), pam[self.compute_uuid])
+
             # TODO(cdent): change this to use the methods built in
             # to the report client to retrieve inventory?
             inventory_url = ('/resource_providers/%s/inventories' %
