@@ -45,7 +45,7 @@ class LibvirtNetVolumeDriverTestCase(
         }
 
     def test_libvirt_sheepdog_driver(self):
-        libvirt_driver = net.LibvirtNetVolumeDriver(self.fake_conn)
+        libvirt_driver = net.LibvirtNetVolumeDriver(self.fake_host)
         connection_info = self.sheepdog_connection(self.vol)
         conf = libvirt_driver.get_config(connection_info, self.disk_info)
         tree = conf.format_dom()
@@ -59,7 +59,7 @@ class LibvirtNetVolumeDriverTestCase(
             'driver_volume_type': 'rbd',
             'data': {
                 'name': '%s/%s' % ('rbd', volume['name']),
-                'auth_enabled': CONF.libvirt.rbd_secret_uuid is not None,
+                'auth_enabled': CONF.libvirt.rbd_user is not None,
                 'auth_username': CONF.libvirt.rbd_user,
                 'secret_type': 'ceph',
                 'secret_uuid': CONF.libvirt.rbd_secret_uuid,
@@ -71,7 +71,7 @@ class LibvirtNetVolumeDriverTestCase(
         }
 
     def test_libvirt_rbd_driver(self):
-        libvirt_driver = net.LibvirtNetVolumeDriver(self.fake_conn)
+        libvirt_driver = net.LibvirtNetVolumeDriver(self.fake_host)
         connection_info = self.rbd_connection(self.vol)
         conf = libvirt_driver.get_config(connection_info, self.disk_info)
         tree = conf.format_dom()
@@ -82,7 +82,7 @@ class LibvirtNetVolumeDriverTestCase(
         libvirt_driver.disconnect_volume(connection_info, "vde")
 
     def test_libvirt_rbd_driver_hosts(self):
-        libvirt_driver = net.LibvirtNetVolumeDriver(self.fake_conn)
+        libvirt_driver = net.LibvirtNetVolumeDriver(self.fake_host)
         connection_info = self.rbd_connection(self.vol)
         hosts = ['example.com', '1.2.3.4', '::1']
         ports = [None, '6790', '6791']
@@ -98,7 +98,7 @@ class LibvirtNetVolumeDriverTestCase(
         libvirt_driver.disconnect_volume(connection_info, "vde")
 
     def test_libvirt_rbd_driver_auth_enabled(self):
-        libvirt_driver = net.LibvirtNetVolumeDriver(self.fake_conn)
+        libvirt_driver = net.LibvirtNetVolumeDriver(self.fake_host)
         connection_info = self.rbd_connection(self.vol)
         secret_type = 'ceph'
         connection_info['data']['auth_enabled'] = True
@@ -114,8 +114,10 @@ class LibvirtNetVolumeDriverTestCase(
         self.assertEqual(self.uuid, tree.find('./auth/secret').get('uuid'))
         libvirt_driver.disconnect_volume(connection_info, "vde")
 
-    def test_libvirt_rbd_driver_auth_enabled_flags_override(self):
-        libvirt_driver = net.LibvirtNetVolumeDriver(self.fake_conn)
+    def test_libvirt_rbd_driver_auth_enabled_flags(self):
+        # The values from the cinder connection_info take precedence over
+        # nova.conf values.
+        libvirt_driver = net.LibvirtNetVolumeDriver(self.fake_host)
         connection_info = self.rbd_connection(self.vol)
         secret_type = 'ceph'
         connection_info['data']['auth_enabled'] = True
@@ -132,13 +134,13 @@ class LibvirtNetVolumeDriverTestCase(
         conf = libvirt_driver.get_config(connection_info, self.disk_info)
         tree = conf.format_dom()
         self._assertNetworkAndProtocolEquals(tree)
-        self.assertEqual(flags_user, tree.find('./auth').get('username'))
+        self.assertEqual(self.user, tree.find('./auth').get('username'))
         self.assertEqual(secret_type, tree.find('./auth/secret').get('type'))
-        self.assertEqual(flags_uuid, tree.find('./auth/secret').get('uuid'))
+        self.assertEqual(self.uuid, tree.find('./auth/secret').get('uuid'))
         libvirt_driver.disconnect_volume(connection_info, "vde")
 
     def test_libvirt_rbd_driver_auth_disabled(self):
-        libvirt_driver = net.LibvirtNetVolumeDriver(self.fake_conn)
+        libvirt_driver = net.LibvirtNetVolumeDriver(self.fake_host)
         connection_info = self.rbd_connection(self.vol)
         secret_type = 'ceph'
         connection_info['data']['auth_enabled'] = False
@@ -153,7 +155,7 @@ class LibvirtNetVolumeDriverTestCase(
         libvirt_driver.disconnect_volume(connection_info, "vde")
 
     def test_libvirt_rbd_driver_auth_disabled_flags_override(self):
-        libvirt_driver = net.LibvirtNetVolumeDriver(self.fake_conn)
+        libvirt_driver = net.LibvirtNetVolumeDriver(self.fake_host)
         connection_info = self.rbd_connection(self.vol)
         secret_type = 'ceph'
         connection_info['data']['auth_enabled'] = False
@@ -184,7 +186,7 @@ class LibvirtNetVolumeDriverTestCase(
                                       mock_find):
         mock_find.return_value = test_volume.FakeSecret()
         mock_create.return_value = test_volume.FakeSecret()
-        libvirt_driver = net.LibvirtNetVolumeDriver(self.fake_conn)
+        libvirt_driver = net.LibvirtNetVolumeDriver(self.fake_host)
         connection_info = self.iscsi_connection(self.vol, self.location,
                                                 self.iqn, auth=True)
         secret_type = 'iscsi'
